@@ -1,31 +1,9 @@
 import os
-
-
-def write_yaml(data=None):
-    if data:
-        r_dict = {
-            "DIRECTORY": data.get("DIRECTORY"),
-            "BASELINE DIRECTORY": data.get("BASELINE DIRECTORY"),
-            "GRADIENT": data.get("GRADIENTS", [10]),
-            "ISOTHERMS": data.get("ISOTHERMS", [190, 220, 350]),
-            "WAVE LENGTHS": data.get("WAVE LENGTHS", [None, None, None, None]),
-            # "RMS": data.get("RMS", False), TODO: Add RMS functionality
-            "TECHNIQUES": data.get("TECHNIQUES"),
-        }
-    else:
-        r_dict = {
-            "DIRECTORY": os.getcwd(),
-            "PROJECT": "DESCRIPTIVE PROJECT TITLE",
-            "TOPICS": ["TANGO", "VOYAGER", "APOSTOLIC", "UNICORN"],
-            "GRADIENTS": [10],
-            "ISOTHERMS": [190, 220, 350],
-            "TECHNIQUES": ["STA", "IR", "GC", "MS", "TG"],
-        }
-    return r_dict
+from aihelper import aiyaml
 
 
 def write_post_yaml(data):
-    new_data = write_yaml(data)
+    new_data = aiyaml.write_directories(data)
     root = data.get("DIRECTORY", os.getcwd())
     project_name = data.get("PROJECT", "<NAME MISSING>")
     project = os.path.join(root, f"Project {project_name}")
